summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_dashboard.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2015-10-04 04:21:35 +0200
committerHolger Levsen <holger@layer-acht.org>2015-10-04 04:21:47 +0200
commit104cb427c5b2e7ddb23a7bd144e8b7327ff1b084 (patch)
treecf679bacc756df80e926160e70d3787a699f9d5f /bin/reproducible_html_dashboard.sh
parent51ed3da77e3e370a077bcbda8f3392ee1675d8a7 (diff)
downloadjenkins.debian.net-104cb427c5b2e7ddb23a7bd144e8b7327ff1b084.tar.xz
reproducible: fix speling error
Diffstat (limited to 'bin/reproducible_html_dashboard.sh')
-rwxr-xr-xbin/reproducible_html_dashboard.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/reproducible_html_dashboard.sh b/bin/reproducible_html_dashboard.sh
index 1a7a6caa..5ec5c1a4 100755
--- a/bin/reproducible_html_dashboard.sh
+++ b/bin/reproducible_html_dashboard.sh
@@ -242,9 +242,9 @@ write_usertag_table() {
}
#
# write build performace stats
#
-write_build_performace_stats() {
+write_build_performance_stats() {
if [ "$ARCH" = "amd64" ] || [ "$ARCH" = "armhf" ] ; then
TIMESPAN_VERBOSE="4 weeks"
TIMESPAN_RAW="28"
@@ -444,7 +444,7 @@ create_main_stats_page() {
for SUITE in $SUITES ; do
write_page " <a href=\"/$SUITE/\"><img src=\"/$SUITE/$ARCH/${TABLE[2]}.png\" class=\"overview\" alt=\"age of oldest reproducible build result in $SUITE/$ARCH\"></a>"
done
- write_build_performace_stats
+ write_build_performance_stats
# other archs: armhf
ARCH="armhf"
write_page "</p><p style=\"clear:both;\">"
@@ -454,7 +454,7 @@ create_main_stats_page() {
write_page " <a href=\"/$SUITE/index_suite_${ARCH}_stats.html\"><img src=\"/$SUITE/$ARCH/${TABLE[0]}.png\" class=\"overview\" alt=\"$SUITE/$ARCH stats\"></a>"
write_page " <a href=\"/${TABLE[1]}_$ARCH.png\"><img src=\"/${TABLE[1]}_$ARCH.png\" class=\"overview\" alt=\"${MAINLABEL[$i]}\"></a>"
write_page " <a href=\"/$SUITE/$ARCH/${TABLE[2]}.png\"><img src=\"/$SUITE/$ARCH/${TABLE[2]}.png\" class=\"overview\" alt=\"age of oldest reproducible build result in $SUITE/$ARCH\"></a>"
- write_build_performace_stats
+ write_build_performance_stats
write_page "</p><p style=\"clear:both;\">"
write_page " <hr />"
# link to index_breakages
@@ -242,9 +242,9 @@ write_usertag_table() {
}
#
-# write build performace stats
+# write build performance stats
#